# vk_maria
[![Telegram vk_maria live](https://img.shields.io/badge/telegram-vk_maria-blue.svg?style=flat-square)](https://t.me/vk_maria_ru)
[![PyPi Package Version](https://img.shields.io/pypi/v/vk_maria.svg?style=flat-square)](https://pypi.python.org/pypi/vk_maria)
[![PyPi Month Downloads](https://img.shields.io/pypi/dm/vk_maria.svg?style=flat-square)](https://pypi.python.org/pypi/vk_maria)
[![PyPi Total Downloads](https://pepy.tech/badge/vk-maria)](https://pepy.tech/project/vk-maria)
[![Supported python versions](https://img.shields.io/pypi/pyversions/vk_maria.svg?style=flat-square)](https://pypi.python.org/pypi/vk_maria)


**vk_maria** очень простой фреймворк для создания ботов сообществ [Vk](https://dev.vk.com/reference>), написанный на Python 3.8.

## Официальные ресурсы vk_maria

- Новости: [@vk_maria](https://t.me/vk_maria_ru)
- Чат комьюнити: [@vk_maria_ru](https://t.me/vk_maria_ru_chat)
- Pip: [vk_maria](https://pypi.org/project/vk-maria/)
- Docs: [ReadTheDocs](https://vk-maria.readthedocs.io/ru/latest/)
- Source: [Github репозиторий](https://github.com/lxstvayne/vk_maria)
- Issues/Bug tracker: [Github issues tracker](https://github.com/lxstvayne/vk_maria/issues)


## Сильные стороны

- Простота и удобство

- Наличие конечных автоматов (FSM)

- Типизированная


## Внести вклад

[Issue Tracker](https://github.com/lxstvayne/vk_maria/issues)

[Исходники](https://github.com/lxstvayne/vk_maria)
